summaryrefslogtreecommitdiff
path: root/src/mesa/shader
diff options
context:
space:
mode:
authorBrian Paul <brianp@vmware.com>2009-08-27 16:54:32 -0600
committerBrian Paul <brianp@vmware.com>2009-08-27 16:54:32 -0600
commite363ec1d08858735c6f2b1454c43f39c96d5bab6 (patch)
treeaf83e165bd5fba58851f6e65ed3071f2c221005d /src/mesa/shader
parentc2ef10803d6c30e13f8f762cc874e3bccc8a2881 (diff)
parent0d7bed9f8973547b675c35c0083996e946d7cecb (diff)
Merge branch 'mesa_7_5_branch'
Diffstat (limited to 'src/mesa/shader')
-rw-r--r--src/mesa/shader/prog_print.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/mesa/shader/prog_print.c b/src/mesa/shader/prog_print.c
index c8346d4293..b71735aa80 100644
--- a/src/mesa/shader/prog_print.c
+++ b/src/mesa/shader/prog_print.c
@@ -533,7 +533,7 @@ void
_mesa_print_alu_instruction(const struct prog_instruction *inst,
const char *opcode_string, GLuint numRegs)
{
- fprint_alu_instruction(stdout, inst, opcode_string,
+ fprint_alu_instruction(stderr, inst, opcode_string,
numRegs, PROG_PRINT_DEBUG, NULL);
}
@@ -757,7 +757,7 @@ _mesa_print_instruction_opt(const struct prog_instruction *inst,
gl_prog_print_mode mode,
const struct gl_program *prog)
{
- return _mesa_fprint_instruction_opt(stdout, inst, indent, mode, prog);
+ return _mesa_fprint_instruction_opt(stderr, inst, indent, mode, prog);
}
@@ -765,7 +765,7 @@ void
_mesa_print_instruction(const struct prog_instruction *inst)
{
/* note: 4th param should be ignored for PROG_PRINT_DEBUG */
- _mesa_fprint_instruction_opt(stdout, inst, 0, PROG_PRINT_DEBUG, NULL);
+ _mesa_fprint_instruction_opt(stderr, inst, 0, PROG_PRINT_DEBUG, NULL);
}
@@ -811,7 +811,7 @@ _mesa_fprint_program_opt(FILE *f,
/**
* Print program to stdout, default options.
*/
void
_mesa_print_program(const struct gl_program *prog)
@@ -884,12 +884,12 @@ _mesa_fprint_program_parameters(FILE *f,
/**
* Print all of a program's parameters/fields to stdout.
*/
void
_mesa_print_program_parameters(GLcontext *ctx, const struct gl_program *prog)
{
- _mesa_fprint_program_parameters(stdout, ctx, prog);
+ _mesa_fprint_program_parameters(stderr, ctx, prog);
}
@@ -929,12 +929,12 @@ _mesa_fprint_parameter_list(FILE *f,
/**
* Print a program parameter list to stdout.
*/
void
_mesa_print_parameter_list(const struct gl_program_parameter_list *list)
{
- _mesa_fprint_parameter_list(stdout, list);
+ _mesa_fprint_parameter_list(stderr, list);
}
@@ -811,7 +811,7 @@ _mesa_fprint_program_opt(FILE *f,
/**
- * Print program to stdout, default options.
+ * Print program to stderr, default options.
*/
void
@@ -884,12 +884,12 @@ _mesa_fprint_program_parameters(FILE *f,
/**
- * Print all of a program's parameters/fields to stdout.
+ * Print all of a program's parameters/fields to stderr.
*/
void
@@ -929,12 +929,12 @@ _mesa_fprint_parameter_list(FILE *f,
/**
- * Print a program parameter list to stdout.
+ * Print a program parameter list to stderr.
*/
void